@@ -60,7 +60,3 @@ allow_partial_matching = list(
   warnPartialMatchAttr = FALSE,
   warnPartialMatchDollar = FALSE
 )
-
-catn = function(..., file = "") {
-  cat(paste0(..., collapse = "\n"), "\n", sep = "", file = file)
-}
